<template>
    <section>
        <div v-if="!showVideo" class="course-preview mb-4" :style="'background-image: url(' + course?.thumbnail + ');'">
            <span v-if="course?.video" @click="playVideo()" class="play-btn d-flex rounded-circle bg-primary px-2">
                <i class="bi bi-play-fill"></i>
            </span>
        </div>
        <video v-if="showVideo" :src="course?.video" width="100%" height="100%" controls autoplay></video>

        <div class="bg-light p-3 rounded-3 mb-4">
            <div class="d-inline-block mb-3 me-2">
                <span class="bg-white px-2 py-1 text-muted rounded">Lifetime Course Access</span>
            </div>

            <div class="d-inline-block mb-3 me-2">
                <span class="bg-white px-2 py-1 text-muted rounded">{{ course?.video_count }} Video Lectures</span>
            </div>

            <div class="d-inline-block mb-3 me-2">
                <span class="bg-white px-2 py-1 text-muted rounded">{{ course?.audio_count }} Audio Content</span>
            </div>

            <div class="d-inline-block mb-3 me-2">
                <span class="bg-white px-2 py-1 text-muted rounded">{{ course?.note_count }} Notes</span>
            </div>

            <div class="d-inline-block mb-3 me-2">
                <span class="bg-white px-2 py-1 text-muted rounded">5 Free Videos</span>
            </div>

            <div v-if="course?.certificate_available" class="d-inline-block mb-3 me-2">
                <span class="bg-white px-2 py-1 text-muted rounded">Certificate Available</span>
            </div>
        </div>

        <div v-if="!course?.is_enrolled" class="enroll-action border border-primary rounded-3 pt-3">
            <div class="text-center mb-4">
                <span class="d-block">Course Fee</span>
                <strong class="fs-2 me-2">$65.5</strong>
                <span class="fs-3 text-muted text-decoration-line-through">$70.5</span>
            </div>

            <router-link v-if="authStore.userData" :to="'/checkout/' + course?.id"
                class="enroll-btn btn btn-primary py-3 w-100">Enroll
                Now<i class="bi bi-arrow-right ms-2"></i></router-link>
        </div>
        <router-link v-else :to="'/play/' + course?.id" class="btn btn-primary w-100">Play Now</router-link>
    </section>
</template>

<style lang="scss" scoped>
.course-preview {
    height: 225px;
    background-size: cover;
    background-position: center;
    background-repeat: no-repeat;
    border-radius: 1rem;
    display: flex;
    align-items: center;
    justify-content: center;
    color: #fff;
    font-size: 2rem;
    font-weight: bold;

    .play-btn {
        cursor: pointer;
        border: 5px solid #ffffffbd;
        border-radius: 50%;
    }
}

.student-count {
    background-color: #f0ffef;
}

.lesson-count {
    background-color: #fff6f5;
}

.resource-count {
    background-color: #f3f9ff;
}

.enroll-action {
    background-color: #FAF6FE;

    .enroll-btn {
        border-top-left-radius: 0;
        border-top-right-radius: 0;
        border-bottom-left-radius: 1rem;
        border-bottom-right-radius: 1rem;
    }
}
</style>

<script setup>
import { ref } from 'vue';
import { useAuthStore } from '@/stores/auth'

const authStore = useAuthStore()

let props = defineProps({
    course: Object
});

const showVideo = ref(false);

function playVideo() {
    showVideo.value = true;
}
</script>
